Validation and Calibration
==========================

The model has been validated using extensive data sets from California, Arizona and Israel.  It has presently been calibrated for the following cultivars:  Acala SJ-2, GC-510, Maxxa, Deltapine 61, and Deltapine 77, Sivon.

The weather related procedures have been tested and calibrated for the following regions: California San Joaquin Valley, Arizona (Phoenix - Tucson area), Israel Coastal Plain, and Israel Upper Galil (Hula valley area).

From version 1.1 and later, advanced users can modify or create their own calibration files - for new cultivars or new weather regions. Check the HelpForAdvancedUsers files for instructions.
